# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import display_pb2 as display__pb2


class DisplayStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.UpdateLanguagePack = channel.unary_unary(
        '/display.Display/UpdateLanguagePack',
        request_serializer=display__pb2.UpdateLanguagePackRequest.SerializeToString,
        response_deserializer=display__pb2.UpdateLanguagePackResponse.FromString,
        )
    self.UpdateLanguagePackMulti = channel.unary_unary(
        '/display.Display/UpdateLanguagePackMulti',
        request_serializer=display__pb2.UpdateLanguagePackMultiRequest.SerializeToString,
        response_deserializer=display__pb2.UpdateLanguagePackMultiResponse.FromString,
        )
    self.UpdateNotice = channel.unary_unary(
        '/display.Display/UpdateNotice',
        request_serializer=display__pb2.UpdateNoticeRequest.SerializeToString,
        response_deserializer=display__pb2.UpdateNoticeResponse.FromString,
        )
    self.UpdateNoticeMulti = channel.unary_unary(
        '/display.Display/UpdateNoticeMulti',
        request_serializer=display__pb2.UpdateNoticeMultiRequest.SerializeToString,
        response_deserializer=display__pb2.UpdateNoticeMultiResponse.FromString,
        )
    self.UpdateBackgroundImage = channel.unary_unary(
        '/display.Display/UpdateBackgroundImage',
        request_serializer=display__pb2.UpdateBackgroundImageRequest.SerializeToString,
        response_deserializer=display__pb2.UpdateBackgroundImageResponse.FromString,
        )
    self.UpdateBackgroundImageMulti = channel.unary_unary(
        '/display.Display/UpdateBackgroundImageMulti',
        request_serializer=display__pb2.UpdateBackgroundImageMultiRequest.SerializeToString,
        response_deserializer=display__pb2.UpdateBackgroundImageMultiResponse.FromString,
        )
    self.UpdateSlideImages = channel.unary_unary(
        '/display.Display/UpdateSlideImages',
        request_serializer=display__pb2.UpdateSlideImagesRequest.SerializeToString,
        response_deserializer=display__pb2.UpdateSlideImagesResponse.FromString,
        )
    self.UpdateSlideImagesMulti = channel.unary_unary(
        '/display.Display/UpdateSlideImagesMulti',
        request_serializer=display__pb2.UpdateSlideImagesMultiRequest.SerializeToString,
        response_deserializer=display__pb2.UpdateSlideImagesMultiResponse.FromString,
        )
    self.UpdateSound = channel.unary_unary(
        '/display.Display/UpdateSound',
        request_serializer=display__pb2.UpdateSoundRequest.SerializeToString,
        response_deserializer=display__pb2.UpdateSoundResponse.FromString,
        )
    self.UpdateSoundMulti = channel.unary_unary(
        '/display.Display/UpdateSoundMulti',
        request_serializer=display__pb2.UpdateSoundMultiRequest.SerializeToString,
        response_deserializer=display__pb2.UpdateSoundMultiResponse.FromString,
        )
    self.GetConfig = channel.unary_unary(
        '/display.Display/GetConfig',
        request_serializer=display__pb2.GetConfigRequest.SerializeToString,
        response_deserializer=display__pb2.GetConfigResponse.FromString,
        )
    self.SetConfig = channel.unary_unary(
        '/display.Display/SetConfig',
        request_serializer=display__pb2.SetConfigRequest.SerializeToString,
        response_deserializer=display__pb2.SetConfigResponse.FromString,
        )
    self.SetConfigMulti = channel.unary_unary(
        '/display.Display/SetConfigMulti',
        request_serializer=display__pb2.SetConfigMultiRequest.SerializeToString,
        response_deserializer=display__pb2.SetConfigMultiResponse.FromString,
        )


class DisplayServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def UpdateLanguagePack(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateLanguagePackMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateNotice(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateNoticeMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateBackgroundImage(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateBackgroundImageMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateSlideImages(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateSlideImagesMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateSound(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpdateSoundMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetConfigMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DisplayServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'UpdateLanguagePack': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateLanguagePack,
          request_deserializer=display__pb2.UpdateLanguagePackRequest.FromString,
          response_serializer=display__pb2.UpdateLanguagePackResponse.SerializeToString,
      ),
      'UpdateLanguagePackMulti': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateLanguagePackMulti,
          request_deserializer=display__pb2.UpdateLanguagePackMultiRequest.FromString,
          response_serializer=display__pb2.UpdateLanguagePackMultiResponse.SerializeToString,
      ),
      'UpdateNotice': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateNotice,
          request_deserializer=display__pb2.UpdateNoticeRequest.FromString,
          response_serializer=display__pb2.UpdateNoticeResponse.SerializeToString,
      ),
      'UpdateNoticeMulti': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateNoticeMulti,
          request_deserializer=display__pb2.UpdateNoticeMultiRequest.FromString,
          response_serializer=display__pb2.UpdateNoticeMultiResponse.SerializeToString,
      ),
      'UpdateBackgroundImage': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateBackgroundImage,
          request_deserializer=display__pb2.UpdateBackgroundImageRequest.FromString,
          response_serializer=display__pb2.UpdateBackgroundImageResponse.SerializeToString,
      ),
      'UpdateBackgroundImageMulti': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateBackgroundImageMulti,
          request_deserializer=display__pb2.UpdateBackgroundImageMultiRequest.FromString,
          response_serializer=display__pb2.UpdateBackgroundImageMultiResponse.SerializeToString,
      ),
      'UpdateSlideImages': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateSlideImages,
          request_deserializer=display__pb2.UpdateSlideImagesRequest.FromString,
          response_serializer=display__pb2.UpdateSlideImagesResponse.SerializeToString,
      ),
      'UpdateSlideImagesMulti': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateSlideImagesMulti,
          request_deserializer=display__pb2.UpdateSlideImagesMultiRequest.FromString,
          response_serializer=display__pb2.UpdateSlideImagesMultiResponse.SerializeToString,
      ),
      'UpdateSound': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateSound,
          request_deserializer=display__pb2.UpdateSoundRequest.FromString,
          response_serializer=display__pb2.UpdateSoundResponse.SerializeToString,
      ),
      'UpdateSoundMulti': grpc.unary_unary_rpc_method_handler(
          servicer.UpdateSoundMulti,
          request_deserializer=display__pb2.UpdateSoundMultiRequest.FromString,
          response_serializer=display__pb2.UpdateSoundMultiResponse.SerializeToString,
      ),
      'GetConfig': grpc.unary_unary_rpc_method_handler(
          servicer.GetConfig,
          request_deserializer=display__pb2.GetConfigRequest.FromString,
          response_serializer=display__pb2.GetConfigResponse.SerializeToString,
      ),
      'SetConfig': grpc.unary_unary_rpc_method_handler(
          servicer.SetConfig,
          request_deserializer=display__pb2.SetConfigRequest.FromString,
          response_serializer=display__pb2.SetConfigResponse.SerializeToString,
      ),
      'SetConfigMulti': grpc.unary_unary_rpc_method_handler(
          servicer.SetConfigMulti,
          request_deserializer=display__pb2.SetConfigMultiRequest.FromString,
          response_serializer=display__pb2.SetConfigMultiResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'display.Display', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import cert_pb2 as cert__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=_b('\n\032com.supremainc.sdk.gatewayP\001Z\027biostar/service/gateway'),
  serialized_pb=_b('\n\rgateway.proto\x12\x07gateway\x1a\ncert.proto\"H\n\x0bGatewayInfo\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12\x11\n\tdeviceIDs\x18\x02 \x03(\r\x12\x13\n\x0bisConnected\x18\x03 \x01(\x08\"\x10\n\x0eGetListRequest\"%\n\x0fGetListResponse\x12\x12\n\ngatewayIDs\x18\x01 \x03(\t\" \n\nGetRequest\x12\x12\n\ngatewayIDs\x18\x01 \x03(\t\"9\n\x0bGetResponse\x12*\n\x0cgatewayInfos\x18\x01 \x03(\x0b\x32\x14.gateway.GatewayInfo\" \n\nAddRequest\x12\x12\n\ngatewayIDs\x18\x01 \x03(\t\"\r\n\x0b\x41\x64\x64Response\"#\n\rDeleteRequest\x12\x12\n\ngatewayIDs\x18\x01 \x03(\t\"\x10\n\x0e\x44\x65leteResponse\"g\n\x18\x43reateCertificateRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12\x1e\n\x07subject\x18\x02 \x01(\x0b\x32\r.cert.PKIName\x12\x18\n\x10\x65xpireAfterYears\x18\x03 \x01(\x05\"D\n\x19\x43reateCertificateResponse\x12\x13\n\x0bgatewayCert\x18\x01 \x01(\t\x12\x12\n\ngatewayKey\x18\x02 \x01(\t\"/\n\x19GetIssuanceHistoryRequest\x12\x12\n\ngatewayIDs\x18\x01 \x03(\t\"\x92\x01\n\x0f\x43\x65rtificateInfo\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12\x1e\n\x07subject\x18\x02 \x01(\x0b\x32\r.cert.PKIName\x12\x10\n\x08serialNO\x18\x03 \x01(\x03\x12\x11\n\tissueDate\x18\x04 \x01(\x03\x12\x12\n\nexpiryDate\x18\x05 \x01(\x03\x12\x13\n\x0b\x62lacklisted\x18\x06 \x01(\x08\"I\n\x1aGetIssuanceHistoryResponse\x12+\n\tcertInfos\x18\x01 \x03(\x0b\x32\x18.gateway.CertificateInfo\"4\n\x1eGetCertificateBlacklistRequest\x12\x12\n\ngatewayIDs\x18\x01 \x03(\t\"N\n\x1fGetCertificateBlacklistResponse\x12+\n\tcertInfos\x18\x01 \x03(\x0b\x32\x18.gateway.CertificateInfo\"F\n\x1e\x41\x64\x64\x43\x65rtificateBlacklistRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12\x11\n\tserialNOs\x18\x02 \x03(\x03\"!\n\x1f\x41\x64\x64\x43\x65rtificateBlacklistResponse\"I\n!DeleteCertificateBlacklistRequest\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12\x11\n\tserialNOs\x18\x02 \x03(\x03\"$\n\"DeleteCertificateBlacklistResponse\"+\n\x16SubscribeStatusRequest\x12\x11\n\tqueueSize\x18\x01 \x01(\x05\"U\n\x0cStatusChange\x12\x11\n\tgatewayID\x18\x01 \x01(\t\x12\x1f\n\x06status\x18\x02 \x01(\x0e\x32\x0f.gateway.Status\x12\x11\n\ttimestamp\x18\x03 \x01(\r*)\n\x06Status\x12\x10\n\x0c\x44ISCONNECTED\x10\x00\x12\r\n\tCONNECTED\x10\x01\x32\xc1\x06\n\x07Gateway\x12<\n\x07GetList\x12\x17.gateway.GetListRequest\x1a\x18.gateway.GetListResponse\x12\x30\n\x03Get\x12\x13.gateway.GetRequest\x1a\x14.gateway.GetResponse\x12\x30\n\x03\x41\x64\x64\x12\x13.gateway.AddRequest\x1a\x14.gateway.AddResponse\x12\x39\n\x06\x44\x65lete\x12\x16.gateway.DeleteRequest\x1a\x17.gateway.DeleteResponse\x12Z\n\x11\x43reateCertificate\x12!.gateway.CreateCertificateRequest\x1a\".gateway.CreateCertificateResponse\x12]\n\x12GetIssuanceHistory\x12\".gateway.GetIssuanceHistoryRequest\x1a#.gateway.GetIssuanceHistoryResponse\x12l\n\x17GetCertificateBlacklist\x12\'.gateway.GetCertificateBlacklistRequest\x1a(.gateway.GetCertificateBlacklistResponse\x12l\n\x17\x41\x64\x64\x43\x65rtificateBlacklist\x12\'.gateway.AddCertificateBlacklistRequest\x1a(.gateway.AddCertificateBlacklistResponse\x12u\n\x1a\x44\x65leteCertificateBlacklist\x12*.gateway.DeleteCertificateBlacklistRequest\x1a+.gateway.DeleteCertificateBlacklistResponse\x12K\n\x0fSubscribeStatus\x12\x1f.gateway.SubscribeStatusRequest\x1a\x15.gateway.StatusChange0\x01\x42\x37\n\x1a\x63om.supremainc.sdk.gatewayP\x01Z\x17\x62iostar/service/gatewayb\x06proto3')
  ,
  dependencies=[cert__pb2.DESCRIPTOR,])

_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='gateway.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DISCONNECTED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONNECTED', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1300,
  serialized_end=1341,
)
_sym_db.RegisterEnumDescriptor(_STATUS)

Status = enum_type_wrapper.EnumTypeWrapper(_STATUS)
DISCONNECTED = 0
CONNECTED = 1



_GATEWAYINFO = _descriptor.Descriptor(
  name='GatewayInfo',
  full_name='gateway.GatewayInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='gateway.GatewayInfo.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='gateway.GatewayInfo.deviceIDs', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isConnected', full_name='gateway.GatewayInfo.isConnected', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=110,
)


_GETLISTREQUEST = _descriptor.Descriptor(
  name='GetListRequest',
  full_name='gateway.GetListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=128,
)


_GETLISTRESPONSE = _descriptor.Descriptor(
  name='GetListResponse',
  full_name='gateway.GetListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayIDs', full_name='gateway.GetListResponse.gatewayIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=130,
  serialized_end=167,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='gateway.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayIDs', full_name='gateway.GetRequest.gatewayIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=201,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='gateway.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayInfos', full_name='gateway.GetResponse.gatewayInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=260,
)


_ADDREQUEST = _descriptor.Descriptor(
  name='AddRequest',
  full_name='gateway.AddRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayIDs', full_name='gateway.AddRequest.gatewayIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=294,
)


_ADDRESPONSE = _descriptor.Descriptor(
  name='AddResponse',
  full_name='gateway.AddResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=296,
  serialized_end=309,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='gateway.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayIDs', full_name='gateway.DeleteRequest.gatewayIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=311,
  serialized_end=346,
)


_DELETERESPONSE = _descriptor.Descriptor(
  name='DeleteResponse',
  full_name='gateway.DeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=364,
)


_CREATECERTIFICATEREQUEST = _descriptor.Descriptor(
  name='CreateCertificateRequest',
  full_name='gateway.CreateCertificateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='gateway.CreateCertificateRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject', full_name='gateway.CreateCertificateRequest.subject', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expireAfterYears', full_name='gateway.CreateCertificateRequest.expireAfterYears', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=469,
)


_CREATECERTIFICATERESPONSE = _descriptor.Descriptor(
  name='CreateCertificateResponse',
  full_name='gateway.CreateCertificateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayCert', full_name='gateway.CreateCertificateResponse.gatewayCert', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gatewayKey', full_name='gateway.CreateCertificateResponse.gatewayKey', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=471,
  serialized_end=539,
)


_GETISSUANCEHISTORYREQUEST = _descriptor.Descriptor(
  name='GetIssuanceHistoryRequest',
  full_name='gateway.GetIssuanceHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayIDs', full_name='gateway.GetIssuanceHistoryRequest.gatewayIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=541,
  serialized_end=588,
)


_CERTIFICATEINFO = _descriptor.Descriptor(
  name='CertificateInfo',
  full_name='gateway.CertificateInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='gateway.CertificateInfo.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subject', full_name='gateway.CertificateInfo.subject', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serialNO', full_name='gateway.CertificateInfo.serialNO', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='issueDate', full_name='gateway.CertificateInfo.issueDate', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiryDate', full_name='gateway.CertificateInfo.expiryDate', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='blacklisted', full_name='gateway.CertificateInfo.blacklisted', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=591,
  serialized_end=737,
)


_GETISSUANCEHISTORYRESPONSE = _descriptor.Descriptor(
  name='GetIssuanceHistoryResponse',
  full_name='gateway.GetIssuanceHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='certInfos', full_name='gateway.GetIssuanceHistoryResponse.certInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=739,
  serialized_end=812,
)


_GETCERTIFICATEBLACKLISTREQUEST = _descriptor.Descriptor(
  name='GetCertificateBlacklistRequest',
  full_name='gateway.GetCertificateBlacklistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayIDs', full_name='gateway.GetCertificateBlacklistRequest.gatewayIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=814,
  serialized_end=866,
)


_GETCERTIFICATEBLACKLISTRESPONSE = _descriptor.Descriptor(
  name='GetCertificateBlacklistResponse',
  full_name='gateway.GetCertificateBlacklistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='certInfos', full_name='gateway.GetCertificateBlacklistResponse.certInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=868,
  serialized_end=946,
)


_ADDCERTIFICATEBLACKLISTREQUEST = _descriptor.Descriptor(
  name='AddCertificateBlacklistRequest',
  full_name='gateway.AddCertificateBlacklistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='gateway.AddCertificateBlacklistRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serialNOs', full_name='gateway.AddCertificateBlacklistRequest.serialNOs', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=948,
  serialized_end=1018,
)


_ADDCERTIFICATEBLACKLISTRESPONSE = _descriptor.Descriptor(
  name='AddCertificateBlacklistResponse',
  full_name='gateway.AddCertificateBlacklistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1020,
  serialized_end=1053,
)


_DELETECERTIFICATEBLACKLISTREQUEST = _descriptor.Descriptor(
  name='DeleteCertificateBlacklistRequest',
  full_name='gateway.DeleteCertificateBlacklistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='gateway.DeleteCertificateBlacklistRequest.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serialNOs', full_name='gateway.DeleteCertificateBlacklistRequest.serialNOs', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1055,
  serialized_end=1128,
)


_DELETECERTIFICATEBLACKLISTRESPONSE = _descriptor.Descriptor(
  name='DeleteCertificateBlacklistResponse',
  full_name='gateway.DeleteCertificateBlacklistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1130,
  serialized_end=1166,
)


_SUBSCRIBESTATUSREQUEST = _descriptor.Descriptor(
  name='SubscribeStatusRequest',
  full_name='gateway.SubscribeStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queueSize', full_name='gateway.SubscribeStatusRequest.queueSize', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1168,
  serialized_end=1211,
)


_STATUSCHANGE = _descriptor.Descriptor(
  name='StatusChange',
  full_name='gateway.StatusChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gatewayID', full_name='gateway.StatusChange.gatewayID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='gateway.StatusChange.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='gateway.StatusChange.timestamp', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1213,
  serialized_end=1298,
)

_GETRESPONSE.fields_by_name['gatewayInfos'].message_type = _GATEWAYINFO
_CREATECERTIFICATEREQUEST.fields_by_name['subject'].message_type = cert__pb2._PKINAME
_CERTIFICATEINFO.fields_by_name['subject'].message_type = cert__pb2._PKINAME
_GETISSUANCEHISTORYRESPONSE.fields_by_name['certInfos'].message_type = _CERTIFICATEINFO
_GETCERTIFICATEBLACKLISTRESPONSE.fields_by_name['certInfos'].message_type = _CERTIFICATEINFO
_STATUSCHANGE.fields_by_name['status'].enum_type = _STATUS
DESCRIPTOR.message_types_by_name['GatewayInfo'] = _GATEWAYINFO
DESCRIPTOR.message_types_by_name['GetListRequest'] = _GETLISTREQUEST
DESCRIPTOR.message_types_by_name['GetListResponse'] = _GETLISTRESPONSE
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.message_types_by_name['AddRequest'] = _ADDREQUEST
DESCRIPTOR.message_types_by_name['AddResponse'] = _ADDRESPONSE
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
DESCRIPTOR.message_types_by_name['DeleteResponse'] = _DELETERESPONSE
DESCRIPTOR.message_types_by_name['CreateCertificateRequest'] = _CREATECERTIFICATEREQUEST
DESCRIPTOR.message_types_by_name['CreateCertificateResponse'] = _CREATECERTIFICATERESPONSE
DESCRIPTOR.message_types_by_name['GetIssuanceHistoryRequest'] = _GETISSUANCEHISTORYREQUEST
DESCRIPTOR.message_types_by_name['CertificateInfo'] = _CERTIFICATEINFO
DESCRIPTOR.message_types_by_name['GetIssuanceHistoryResponse'] = _GETISSUANCEHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['GetCertificateBlacklistRequest'] = _GETCERTIFICATEBLACKLISTREQUEST
DESCRIPTOR.message_types_by_name['GetCertificateBlacklistResponse'] = _GETCERTIFICATEBLACKLISTRESPONSE
DESCRIPTOR.message_types_by_name['AddCertificateBlacklistRequest'] = _ADDCERTIFICATEBLACKLISTREQUEST
DESCRIPTOR.message_types_by_name['AddCertificateBlacklistResponse'] = _ADDCERTIFICATEBLACKLISTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteCertificateBlacklistRequest'] = _DELETECERTIFICATEBLACKLISTREQUEST
DESCRIPTOR.message_types_by_name['DeleteCertificateBlacklistResponse'] = _DELETECERTIFICATEBLACKLISTRESPONSE
DESCRIPTOR.message_types_by_name['SubscribeStatusRequest'] = _SUBSCRIBESTATUSREQUEST
DESCRIPTOR.message_types_by_name['StatusChange'] = _STATUSCHANGE
DESCRIPTOR.enum_types_by_name['Status'] = _STATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GatewayInfo = _reflection.GeneratedProtocolMessageType('GatewayInfo', (_message.Message,), dict(
  DESCRIPTOR = _GATEWAYINFO,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GatewayInfo)
  ))
_sym_db.RegisterMessage(GatewayInfo)

GetListRequest = _reflection.GeneratedProtocolMessageType('GetListRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTREQUEST,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetListRequest)
  ))
_sym_db.RegisterMessage(GetListRequest)

GetListResponse = _reflection.GeneratedProtocolMessageType('GetListResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETLISTRESPONSE,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetListResponse)
  ))
_sym_db.RegisterMessage(GetListResponse)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRESPONSE,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetResponse)
  ))
_sym_db.RegisterMessage(GetResponse)

AddRequest = _reflection.GeneratedProtocolMessageType('AddRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDREQUEST,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.AddRequest)
  ))
_sym_db.RegisterMessage(AddRequest)

AddResponse = _reflection.GeneratedProtocolMessageType('AddResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDRESPONSE,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.AddResponse)
  ))
_sym_db.RegisterMessage(AddResponse)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEREQUEST,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteRequest)
  ))
_sym_db.RegisterMessage(DeleteRequest)

DeleteResponse = _reflection.GeneratedProtocolMessageType('DeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETERESPONSE,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteResponse)
  ))
_sym_db.RegisterMessage(DeleteResponse)

CreateCertificateRequest = _reflection.GeneratedProtocolMessageType('CreateCertificateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CREATECERTIFICATEREQUEST,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateCertificateRequest)
  ))
_sym_db.RegisterMessage(CreateCertificateRequest)

CreateCertificateResponse = _reflection.GeneratedProtocolMessageType('CreateCertificateResponse', (_message.Message,), dict(
  DESCRIPTOR = _CREATECERTIFICATERESPONSE,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateCertificateResponse)
  ))
_sym_db.RegisterMessage(CreateCertificateResponse)

GetIssuanceHistoryRequest = _reflection.GeneratedProtocolMessageType('GetIssuanceHistoryRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETISSUANCEHISTORYREQUEST,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetIssuanceHistoryRequest)
  ))
_sym_db.RegisterMessage(GetIssuanceHistoryRequest)

CertificateInfo = _reflection.GeneratedProtocolMessageType('CertificateInfo', (_message.Message,), dict(
  DESCRIPTOR = _CERTIFICATEINFO,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CertificateInfo)
  ))
_sym_db.RegisterMessage(CertificateInfo)

GetIssuanceHistoryResponse = _reflection.GeneratedProtocolMessageType('GetIssuanceHistoryResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETISSUANCEHISTORYRESPONSE,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetIssuanceHistoryResponse)
  ))
_sym_db.RegisterMessage(GetIssuanceHistoryResponse)

GetCertificateBlacklistRequest = _reflection.GeneratedProtocolMessageType('GetCertificateBlacklistRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCERTIFICATEBLACKLISTREQUEST,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetCertificateBlacklistRequest)
  ))
_sym_db.RegisterMessage(GetCertificateBlacklistRequest)

GetCertificateBlacklistResponse = _reflection.GeneratedProtocolMessageType('GetCertificateBlacklistResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCERTIFICATEBLACKLISTRESPONSE,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetCertificateBlacklistResponse)
  ))
_sym_db.RegisterMessage(GetCertificateBlacklistResponse)

AddCertificateBlacklistRequest = _reflection.GeneratedProtocolMessageType('AddCertificateBlacklistRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDCERTIFICATEBLACKLISTREQUEST,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.AddCertificateBlacklistRequest)
  ))
_sym_db.RegisterMessage(AddCertificateBlacklistRequest)

AddCertificateBlacklistResponse = _reflection.GeneratedProtocolMessageType('AddCertificateBlacklistResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDCERTIFICATEBLACKLISTRESPONSE,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.AddCertificateBlacklistResponse)
  ))
_sym_db.RegisterMessage(AddCertificateBlacklistResponse)

DeleteCertificateBlacklistRequest = _reflection.GeneratedProtocolMessageType('DeleteCertificateBlacklistRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETECERTIFICATEBLACKLISTREQUEST,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteCertificateBlacklistRequest)
  ))
_sym_db.RegisterMessage(DeleteCertificateBlacklistRequest)

DeleteCertificateBlacklistResponse = _reflection.GeneratedProtocolMessageType('DeleteCertificateBlacklistResponse', (_message.Message,), dict(
  DESCRIPTOR = _DELETECERTIFICATEBLACKLISTRESPONSE,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteCertificateBlacklistResponse)
  ))
_sym_db.RegisterMessage(DeleteCertificateBlacklistResponse)

SubscribeStatusRequest = _reflection.GeneratedProtocolMessageType('SubscribeStatusRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBESTATUSREQUEST,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.SubscribeStatusRequest)
  ))
_sym_db.RegisterMessage(SubscribeStatusRequest)

StatusChange = _reflection.GeneratedProtocolMessageType('StatusChange', (_message.Message,), dict(
  DESCRIPTOR = _STATUSCHANGE,
  __module__ = 'gateway_pb2'
  # @@protoc_insertion_point(class_scope:gateway.StatusChange)
  ))
_sym_db.RegisterMessage(StatusChange)


DESCRIPTOR._options = None

_GATEWAY = _descriptor.ServiceDescriptor(
  name='Gateway',
  full_name='gateway.Gateway',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1344,
  serialized_end=2177,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetList',
    full_name='gateway.Gateway.GetList',
    index=0,
    containing_service=None,
    input_type=_GETLISTREQUEST,
    output_type=_GETLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='gateway.Gateway.Get',
    index=1,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Add',
    full_name='gateway.Gateway.Add',
    index=2,
    containing_service=None,
    input_type=_ADDREQUEST,
    output_type=_ADDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='gateway.Gateway.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=_DELETERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateCertificate',
    full_name='gateway.Gateway.CreateCertificate',
    index=4,
    containing_service=None,
    input_type=_CREATECERTIFICATEREQUEST,
    output_type=_CREATECERTIFICATERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetIssuanceHistory',
    full_name='gateway.Gateway.GetIssuanceHistory',
    index=5,
    containing_service=None,
    input_type=_GETISSUANCEHISTORYREQUEST,
    output_type=_GETISSUANCEHISTORYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetCertificateBlacklist',
    full_name='gateway.Gateway.GetCertificateBlacklist',
    index=6,
    containing_service=None,
    input_type=_GETCERTIFICATEBLACKLISTREQUEST,
    output_type=_GETCERTIFICATEBLACKLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddCertificateBlacklist',
    full_name='gateway.Gateway.AddCertificateBlacklist',
    index=7,
    containing_service=None,
    input_type=_ADDCERTIFICATEBLACKLISTREQUEST,
    output_type=_ADDCERTIFICATEBLACKLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCertificateBlacklist',
    full_name='gateway.Gateway.DeleteCertificateBlacklist',
    index=8,
    containing_service=None,
    input_type=_DELETECERTIFICATEBLACKLISTREQUEST,
    output_type=_DELETECERTIFICATEBLACKLISTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeStatus',
    full_name='gateway.Gateway.SubscribeStatus',
    index=9,
    containing_service=None,
    input_type=_SUBSCRIBESTATUSREQUEST,
    output_type=_STATUSCHANGE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_GATEWAY)

DESCRIPTOR.services_by_name['Gateway'] = _GATEWAY

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import operator_pb2 as operator__pb2


class OperatorStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetList = channel.unary_unary(
        '/operator.Operator/GetList',
        request_serializer=operator__pb2.GetListRequest.SerializeToString,
        response_deserializer=operator__pb2.GetListResponse.FromString,
        )
    self.Add = channel.unary_unary(
        '/operator.Operator/Add',
        request_serializer=operator__pb2.AddRequest.SerializeToString,
        response_deserializer=operator__pb2.AddResponse.FromString,
        )
    self.AddMulti = channel.unary_unary(
        '/operator.Operator/AddMulti',
        request_serializer=operator__pb2.AddMultiRequest.SerializeToString,
        response_deserializer=operator__pb2.AddMultiResponse.FromString,
        )
    self.Delete = channel.unary_unary(
        '/operator.Operator/Delete',
        request_serializer=operator__pb2.DeleteRequest.SerializeToString,
        response_deserializer=operator__pb2.DeleteResponse.FromString,
        )
    self.DeleteMulti = channel.unary_unary(
        '/operator.Operator/DeleteMulti',
        request_serializer=operator__pb2.DeleteMultiRequest.SerializeToString,
        response_deserializer=operator__pb2.DeleteMultiResponse.FromString,
        )
    self.DeleteAll = channel.unary_unary(
        '/operator.Operator/DeleteAll',
        request_serializer=operator__pb2.DeleteAllRequest.SerializeToString,
        response_deserializer=operator__pb2.DeleteAllResponse.FromString,
        )
    self.DeleteAllMulti = channel.unary_unary(
        '/operator.Operator/DeleteAllMulti',
        request_serializer=operator__pb2.DeleteAllMultiRequest.SerializeToString,
        response_deserializer=operator__pb2.DeleteAllMultiResponse.FromString,
        )


class OperatorServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetList(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Add(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAll(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteAllMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_OperatorServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetList': grpc.unary_unary_rpc_method_handler(
          servicer.GetList,
          request_deserializer=operator__pb2.GetListRequest.FromString,
          response_serializer=operator__pb2.GetListResponse.SerializeToString,
      ),
      'Add': grpc.unary_unary_rpc_method_handler(
          servicer.Add,
          request_deserializer=operator__pb2.AddRequest.FromString,
          response_serializer=operator__pb2.AddResponse.SerializeToString,
      ),
      'AddMulti': grpc.unary_unary_rpc_method_handler(
          servicer.AddMulti,
          request_deserializer=operator__pb2.AddMultiRequest.FromString,
          response_serializer=operator__pb2.AddMultiResponse.SerializeToString,
      ),
      'Delete': grpc.unary_unary_rpc_method_handler(
          servicer.Delete,
          request_deserializer=operator__pb2.DeleteRequest.FromString,
          response_serializer=operator__pb2.DeleteResponse.SerializeToString,
      ),
      'DeleteMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteMulti,
          request_deserializer=operator__pb2.DeleteMultiRequest.FromString,
          response_serializer=operator__pb2.DeleteMultiResponse.SerializeToString,
      ),
      'DeleteAll': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAll,
          request_deserializer=operator__pb2.DeleteAllRequest.FromString,
          response_serializer=operator__pb2.DeleteAllResponse.SerializeToString,
      ),
      'DeleteAllMulti': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteAllMulti,
          request_deserializer=operator__pb2.DeleteAllMultiRequest.FromString,
          response_serializer=operator__pb2.DeleteAllMultiResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'operator.Operator', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: config.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2
from biostarPython.service import system_pb2 as system__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='config.proto',
  package='config',
  syntax='proto3',
  serialized_options=_b('\n\031com.supremainc.sdk.configP\001Z\026biostar/service/config'),
  serialized_pb=_b('\n\x0c\x63onfig.proto\x12\x06\x63onfig\x1a\terr.proto\x1a\x0csystem.proto\"$\n\x10GetSystemRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"9\n\x11GetSystemResponse\x12$\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x14.system.SystemConfig\"J\n\x10SetSystemRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.system.SystemConfig\"\x13\n\x11SetSystemResponse\"P\n\x15SetSystemMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12$\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x14.system.SystemConfig\"B\n\x16SetSystemMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse2\xdd\x01\n\x06\x43onfig\x12@\n\tGetSystem\x12\x18.config.GetSystemRequest\x1a\x19.config.GetSystemResponse\x12@\n\tSetSystem\x12\x18.config.SetSystemRequest\x1a\x19.config.SetSystemResponse\x12O\n\x0eSetSystemMulti\x12\x1d.config.SetSystemMultiRequest\x1a\x1e.config.SetSystemMultiResponseB5\n\x19\x63om.supremainc.sdk.configP\x01Z\x16\x62iostar/service/configb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,system__pb2.DESCRIPTOR,])




_GETSYSTEMREQUEST = _descriptor.Descriptor(
  name='GetSystemRequest',
  full_name='config.GetSystemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='config.GetSystemRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=85,
)


_GETSYSTEMRESPONSE = _descriptor.Descriptor(
  name='GetSystemResponse',
  full_name='config.GetSystemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='config.GetSystemResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=144,
)


_SETSYSTEMREQUEST = _descriptor.Descriptor(
  name='SetSystemRequest',
  full_name='config.SetSystemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='config.SetSystemRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='config.SetSystemRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=220,
)


_SETSYSTEMRESPONSE = _descriptor.Descriptor(
  name='SetSystemResponse',
  full_name='config.SetSystemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=241,
)


_SETSYSTEMMULTIREQUEST = _descriptor.Descriptor(
  name='SetSystemMultiRequest',
  full_name='config.SetSystemMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='config.SetSystemMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='config.SetSystemMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=323,
)


_SETSYSTEMMULTIRESPONSE = _descriptor.Descriptor(
  name='SetSystemMultiResponse',
  full_name='config.SetSystemMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='config.SetSystemMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=325,
  serialized_end=391,
)

_GETSYSTEMRESPONSE.fields_by_name['config'].message_type = system__pb2._SYSTEMCONFIG
_SETSYSTEMREQUEST.fields_by_name['config'].message_type = system__pb2._SYSTEMCONFIG
_SETSYSTEMMULTIREQUEST.fields_by_name['config'].message_type = system__pb2._SYSTEMCONFIG
_SETSYSTEMMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['GetSystemRequest'] = _GETSYSTEMREQUEST
DESCRIPTOR.message_types_by_name['GetSystemResponse'] = _GETSYSTEMRESPONSE
DESCRIPTOR.message_types_by_name['SetSystemRequest'] = _SETSYSTEMREQUEST
DESCRIPTOR.message_types_by_name['SetSystemResponse'] = _SETSYSTEMRESPONSE
DESCRIPTOR.message_types_by_name['SetSystemMultiRequest'] = _SETSYSTEMMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetSystemMultiResponse'] = _SETSYSTEMMULTIRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetSystemRequest = _reflection.GeneratedProtocolMessageType('GetSystemRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETSYSTEMREQUEST,
  __module__ = 'config_pb2'
  # @@protoc_insertion_point(class_scope:config.GetSystemRequest)
  ))
_sym_db.RegisterMessage(GetSystemRequest)

GetSystemResponse = _reflection.GeneratedProtocolMessageType('GetSystemResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETSYSTEMRESPONSE,
  __module__ = 'config_pb2'
  # @@protoc_insertion_point(class_scope:config.GetSystemResponse)
  ))
_sym_db.RegisterMessage(GetSystemResponse)

SetSystemRequest = _reflection.GeneratedProtocolMessageType('SetSystemRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETSYSTEMREQUEST,
  __module__ = 'config_pb2'
  # @@protoc_insertion_point(class_scope:config.SetSystemRequest)
  ))
_sym_db.RegisterMessage(SetSystemRequest)

SetSystemResponse = _reflection.GeneratedProtocolMessageType('SetSystemResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETSYSTEMRESPONSE,
  __module__ = 'config_pb2'
  # @@protoc_insertion_point(class_scope:config.SetSystemResponse)
  ))
_sym_db.RegisterMessage(SetSystemResponse)

SetSystemMultiRequest = _reflection.GeneratedProtocolMessageType('SetSystemMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETSYSTEMMULTIREQUEST,
  __module__ = 'config_pb2'
  # @@protoc_insertion_point(class_scope:config.SetSystemMultiRequest)
  ))
_sym_db.RegisterMessage(SetSystemMultiRequest)

SetSystemMultiResponse = _reflection.GeneratedProtocolMessageType('SetSystemMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETSYSTEMMULTIRESPONSE,
  __module__ = 'config_pb2'
  # @@protoc_insertion_point(class_scope:config.SetSystemMultiResponse)
  ))
_sym_db.RegisterMessage(SetSystemMultiResponse)


DESCRIPTOR._options = None

_CONFIG = _descriptor.ServiceDescriptor(
  name='Config',
  full_name='config.Config',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=394,
  serialized_end=615,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetSystem',
    full_name='config.Config.GetSystem',
    index=0,
    containing_service=None,
    input_type=_GETSYSTEMREQUEST,
    output_type=_GETSYSTEMRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetSystem',
    full_name='config.Config.SetSystem',
    index=1,
    containing_service=None,
    input_type=_SETSYSTEMREQUEST,
    output_type=_SETSYSTEMRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetSystemMulti',
    full_name='config.Config.SetSystemMulti',
    index=2,
    containing_service=None,
    input_type=_SETSYSTEMMULTIREQUEST,
    output_type=_SETSYSTEMMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONFIG)

DESCRIPTOR.services_by_name['Config'] = _CONFIG

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from biostarPython.service import device_pb2 as device__pb2


class DeviceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetInfo = channel.unary_unary(
        '/device.Device/GetInfo',
        request_serializer=device__pb2.GetInfoRequest.SerializeToString,
        response_deserializer=device__pb2.GetInfoResponse.FromString,
        )
    self.GetCapabilityInfo = channel.unary_unary(
        '/device.Device/GetCapabilityInfo',
        request_serializer=device__pb2.GetCapabilityInfoRequest.SerializeToString,
        response_deserializer=device__pb2.GetCapabilityInfoResponse.FromString,
        )
    self.DeleteRootCA = channel.unary_unary(
        '/device.Device/DeleteRootCA',
        request_serializer=device__pb2.DeleteRootCARequest.SerializeToString,
        response_deserializer=device__pb2.DeleteRootCAResponse.FromString,
        )
    self.Lock = channel.unary_unary(
        '/device.Device/Lock',
        request_serializer=device__pb2.LockRequest.SerializeToString,
        response_deserializer=device__pb2.LockResponse.FromString,
        )
    self.LockMulti = channel.unary_unary(
        '/device.Device/LockMulti',
        request_serializer=device__pb2.LockMultiRequest.SerializeToString,
        response_deserializer=device__pb2.LockMultiResponse.FromString,
        )
    self.Unlock = channel.unary_unary(
        '/device.Device/Unlock',
        request_serializer=device__pb2.UnlockRequest.SerializeToString,
        response_deserializer=device__pb2.UnlockResponse.FromString,
        )
    self.UnlockMulti = channel.unary_unary(
        '/device.Device/UnlockMulti',
        request_serializer=device__pb2.UnlockMultiRequest.SerializeToString,
        response_deserializer=device__pb2.UnlockMultiResponse.FromString,
        )
    self.Reboot = channel.unary_unary(
        '/device.Device/Reboot',
        request_serializer=device__pb2.RebootRequest.SerializeToString,
        response_deserializer=device__pb2.RebootResponse.FromString,
        )
    self.RebootMulti = channel.unary_unary(
        '/device.Device/RebootMulti',
        request_serializer=device__pb2.RebootMultiRequest.SerializeToString,
        response_deserializer=device__pb2.RebootMultiResponse.FromString,
        )
    self.FactoryReset = channel.unary_unary(
        '/device.Device/FactoryReset',
        request_serializer=device__pb2.FactoryResetRequest.SerializeToString,
        response_deserializer=device__pb2.FactoryResetResponse.FromString,
        )
    self.FactoryResetMulti = channel.unary_unary(
        '/device.Device/FactoryResetMulti',
        request_serializer=device__pb2.FactoryResetMultiRequest.SerializeToString,
        response_deserializer=device__pb2.FactoryResetMultiResponse.FromString,
        )
    self.ClearDB = channel.unary_unary(
        '/device.Device/ClearDB',
        request_serializer=device__pb2.ClearDBRequest.SerializeToString,
        response_deserializer=device__pb2.ClearDBResponse.FromString,
        )
    self.ClearDBMulti = channel.unary_unary(
        '/device.Device/ClearDBMulti',
        request_serializer=device__pb2.ClearDBMultiRequest.SerializeToString,
        response_deserializer=device__pb2.ClearDBMultiResponse.FromString,
        )
    self.ResetConfig = channel.unary_unary(
        '/device.Device/ResetConfig',
        request_serializer=device__pb2.ResetConfigRequest.SerializeToString,
        response_deserializer=device__pb2.ResetConfigResponse.FromString,
        )
    self.ResetConfigMulti = channel.unary_unary(
        '/device.Device/ResetConfigMulti',
        request_serializer=device__pb2.ResetConfigMultiRequest.SerializeToString,
        response_deserializer=device__pb2.ResetConfigMultiResponse.FromString,
        )
    self.UpgradeFirmware = channel.unary_unary(
        '/device.Device/UpgradeFirmware',
        request_serializer=device__pb2.UpgradeFirmwareRequest.SerializeToString,
        response_deserializer=device__pb2.UpgradeFirmwareResponse.FromString,
        )
    self.UpgradeFirmwareMulti = channel.unary_unary(
        '/device.Device/UpgradeFirmwareMulti',
        request_serializer=device__pb2.UpgradeFirmwareMultiRequest.SerializeToString,
        response_deserializer=device__pb2.UpgradeFirmwareMultiResponse.FromString,
        )
    self.GetHashKey = channel.unary_unary(
        '/device.Device/GetHashKey',
        request_serializer=device__pb2.GetHashKeyRequest.SerializeToString,
        response_deserializer=device__pb2.GetHashKeyResponse.FromString,
        )
    self.SetHashKey = channel.unary_unary(
        '/device.Device/SetHashKey',
        request_serializer=device__pb2.SetHashKeyRequest.SerializeToString,
        response_deserializer=device__pb2.SetHashKeyResponse.FromString,
        )


class DeviceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def GetInfo(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetCapabilityInfo(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def DeleteRootCA(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Lock(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def LockMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Unlock(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UnlockMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Reboot(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RebootMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def FactoryReset(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def FactoryResetMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ClearDB(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ClearDBMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ResetConfig(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def ResetConfigMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpgradeFirmware(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def UpgradeFirmwareMulti(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetHashKey(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetHashKey(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_DeviceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetInfo': grpc.unary_unary_rpc_method_handler(
          servicer.GetInfo,
          request_deserializer=device__pb2.GetInfoRequest.FromString,
          response_serializer=device__pb2.GetInfoResponse.SerializeToString,
      ),
      'GetCapabilityInfo': grpc.unary_unary_rpc_method_handler(
          servicer.GetCapabilityInfo,
          request_deserializer=device__pb2.GetCapabilityInfoRequest.FromString,
          response_serializer=device__pb2.GetCapabilityInfoResponse.SerializeToString,
      ),
      'DeleteRootCA': grpc.unary_unary_rpc_method_handler(
          servicer.DeleteRootCA,
          request_deserializer=device__pb2.DeleteRootCARequest.FromString,
          response_serializer=device__pb2.DeleteRootCAResponse.SerializeToString,
      ),
      'Lock': grpc.unary_unary_rpc_method_handler(
          servicer.Lock,
          request_deserializer=device__pb2.LockRequest.FromString,
          response_serializer=device__pb2.LockResponse.SerializeToString,
      ),
      'LockMulti': grpc.unary_unary_rpc_method_handler(
          servicer.LockMulti,
          request_deserializer=device__pb2.LockMultiRequest.FromString,
          response_serializer=device__pb2.LockMultiResponse.SerializeToString,
      ),
      'Unlock': grpc.unary_unary_rpc_method_handler(
          servicer.Unlock,
          request_deserializer=device__pb2.UnlockRequest.FromString,
          response_serializer=device__pb2.UnlockResponse.SerializeToString,
      ),
      'UnlockMulti': grpc.unary_unary_rpc_method_handler(
          servicer.UnlockMulti,
          request_deserializer=device__pb2.UnlockMultiRequest.FromString,
          response_serializer=device__pb2.UnlockMultiResponse.SerializeToString,
      ),
      'Reboot': grpc.unary_unary_rpc_method_handler(
          servicer.Reboot,
          request_deserializer=device__pb2.RebootRequest.FromString,
          response_serializer=device__pb2.RebootResponse.SerializeToString,
      ),
      'RebootMulti': grpc.unary_unary_rpc_method_handler(
          servicer.RebootMulti,
          request_deserializer=device__pb2.RebootMultiRequest.FromString,
          response_serializer=device__pb2.RebootMultiResponse.SerializeToString,
      ),
      'FactoryReset': grpc.unary_unary_rpc_method_handler(
          servicer.FactoryReset,
          request_deserializer=device__pb2.FactoryResetRequest.FromString,
          response_serializer=device__pb2.FactoryResetResponse.SerializeToString,
      ),
      'FactoryResetMulti': grpc.unary_unary_rpc_method_handler(
          servicer.FactoryResetMulti,
          request_deserializer=device__pb2.FactoryResetMultiRequest.FromString,
          response_serializer=device__pb2.FactoryResetMultiResponse.SerializeToString,
      ),
      'ClearDB': grpc.unary_unary_rpc_method_handler(
          servicer.ClearDB,
          request_deserializer=device__pb2.ClearDBRequest.FromString,
          response_serializer=device__pb2.ClearDBResponse.SerializeToString,
      ),
      'ClearDBMulti': grpc.unary_unary_rpc_method_handler(
          servicer.ClearDBMulti,
          request_deserializer=device__pb2.ClearDBMultiRequest.FromString,
          response_serializer=device__pb2.ClearDBMultiResponse.SerializeToString,
      ),
      'ResetConfig': grpc.unary_unary_rpc_method_handler(
          servicer.ResetConfig,
          request_deserializer=device__pb2.ResetConfigRequest.FromString,
          response_serializer=device__pb2.ResetConfigResponse.SerializeToString,
      ),
      'ResetConfigMulti': grpc.unary_unary_rpc_method_handler(
          servicer.ResetConfigMulti,
          request_deserializer=device__pb2.ResetConfigMultiRequest.FromString,
          response_serializer=device__pb2.ResetConfigMultiResponse.SerializeToString,
      ),
      'UpgradeFirmware': grpc.unary_unary_rpc_method_handler(
          servicer.UpgradeFirmware,
          request_deserializer=device__pb2.UpgradeFirmwareRequest.FromString,
          response_serializer=device__pb2.UpgradeFirmwareResponse.SerializeToString,
      ),
      'UpgradeFirmwareMulti': grpc.unary_unary_rpc_method_handler(
          servicer.UpgradeFirmwareMulti,
          request_deserializer=device__pb2.UpgradeFirmwareMultiRequest.FromString,
          response_serializer=device__pb2.UpgradeFirmwareMultiResponse.SerializeToString,
      ),
      'GetHashKey': grpc.unary_unary_rpc_method_handler(
          servicer.GetHashKey,
          request_deserializer=device__pb2.GetHashKeyRequest.FromString,
          response_serializer=device__pb2.GetHashKeyResponse.SerializeToString,
      ),
      'SetHashKey': grpc.unary_unary_rpc_method_handler(
          servicer.SetHashKey,
          request_deserializer=device__pb2.SetHashKeyRequest.FromString,
          response_serializer=device__pb2.SetHashKeyResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'device.Device', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: input.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from biostarPython.service import err_pb2 as err__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='input.proto',
  package='input',
  syntax='proto3',
  serialized_options=_b('\n\030com.supremainc.sdk.inputP\001Z\025biostar/service/input'),
  serialized_pb=_b('\n\x0binput.proto\x12\x05input\x1a\terr.proto\":\n\x14SupervisedInputRange\x12\x10\n\x08MinValue\x18\x01 \x01(\r\x12\x10\n\x08MaxValue\x18\x02 \x01(\r\"\xc1\x01\n\x15SupervisedInputConfig\x12*\n\x05short\x18\x01 \x01(\x0b\x32\x1b.input.SupervisedInputRange\x12)\n\x04open\x18\x02 \x01(\x0b\x32\x1b.input.SupervisedInputRange\x12\'\n\x02on\x18\x03 \x01(\x0b\x32\x1b.input.SupervisedInputRange\x12(\n\x03off\x18\x04 \x01(\x0b\x32\x1b.input.SupervisedInputRange\"\x88\x01\n\x0fSupervisedInput\x12\x11\n\tportIndex\x18\x01 \x01(\r\x12\x34\n\nregistance\x18\x03 \x01(\x0e\x32 .input.SupervisedRegistanceValue\x12,\n\x06\x63onfig\x18\x04 \x01(\x0b\x32\x1c.input.SupervisedInputConfig\"q\n\x0bInputConfig\x12\x12\n\nnumOfInput\x18\x01 \x01(\r\x12\x1c\n\x14numOfSupervisedInput\x18\x02 \x01(\r\x12\x30\n\x10supervisedInputs\x18\x03 \x03(\x0b\x32\x16.input.SupervisedInput\"$\n\x10GetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\"7\n\x11GetConfigResponse\x12\"\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x12.input.InputConfig\"H\n\x10SetConfigRequest\x12\x10\n\x08\x64\x65viceID\x18\x01 \x01(\r\x12\"\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x12.input.InputConfig\"\x13\n\x11SetConfigResponse\"N\n\x15SetConfigMultiRequest\x12\x11\n\tdeviceIDs\x18\x01 \x03(\r\x12\"\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x12.input.InputConfig\"B\n\x16SetConfigMultiResponse\x12(\n\x0c\x64\x65viceErrors\x18\x01 \x03(\x0b\x32\x12.err.ErrorResponse*\x98\x01\n\x19SupervisedRegistanceValue\x12\x15\n\x11SUPERVISED_REG_1K\x10\x00\x12\x17\n\x13SUPERVISED_REG_2_2K\x10\x01\x12\x17\n\x13SUPERVISED_REG_4_7K\x10\x02\x12\x16\n\x12SUPERVISED_REG_10K\x10\x03\x12\x1a\n\x15SUPERVISED_REG_CUSTOM\x10\xff\x01\x32\xd6\x01\n\x05Input\x12>\n\tGetConfig\x12\x17.input.GetConfigRequest\x1a\x18.input.GetConfigResponse\x12>\n\tSetConfig\x12\x17.input.SetConfigRequest\x1a\x18.input.SetConfigResponse\x12M\n\x0eSetConfigMulti\x12\x1c.input.SetConfigMultiRequest\x1a\x1d.input.SetConfigMultiResponseB3\n\x18\x63om.supremainc.sdk.inputP\x01Z\x15\x62iostar/service/inputb\x06proto3')
  ,
  dependencies=[err__pb2.DESCRIPTOR,])

_SUPERVISEDREGISTANCEVALUE = _descriptor.EnumDescriptor(
  name='SupervisedRegistanceValue',
  full_name='input.SupervisedRegistanceValue',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUPERVISED_REG_1K', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUPERVISED_REG_2_2K', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUPERVISED_REG_4_7K', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUPERVISED_REG_10K', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUPERVISED_REG_CUSTOM', index=4, number=255,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=882,
  serialized_end=1034,
)
_sym_db.RegisterEnumDescriptor(_SUPERVISEDREGISTANCEVALUE)

SupervisedRegistanceValue = enum_type_wrapper.EnumTypeWrapper(_SUPERVISEDREGISTANCEVALUE)
SUPERVISED_REG_1K = 0
SUPERVISED_REG_2_2K = 1
SUPERVISED_REG_4_7K = 2
SUPERVISED_REG_10K = 3
SUPERVISED_REG_CUSTOM = 255



_SUPERVISEDINPUTRANGE = _descriptor.Descriptor(
  name='SupervisedInputRange',
  full_name='input.SupervisedInputRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='MinValue', full_name='input.SupervisedInputRange.MinValue', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='MaxValue', full_name='input.SupervisedInputRange.MaxValue', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=91,
)


_SUPERVISEDINPUTCONFIG = _descriptor.Descriptor(
  name='SupervisedInputConfig',
  full_name='input.SupervisedInputConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='short', full_name='input.SupervisedInputConfig.short', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open', full_name='input.SupervisedInputConfig.open', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='on', full_name='input.SupervisedInputConfig.on', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='off', full_name='input.SupervisedInputConfig.off', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=287,
)


_SUPERVISEDINPUT = _descriptor.Descriptor(
  name='SupervisedInput',
  full_name='input.SupervisedInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='portIndex', full_name='input.SupervisedInput.portIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='registance', full_name='input.SupervisedInput.registance', index=1,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='input.SupervisedInput.config', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=290,
  serialized_end=426,
)


_INPUTCONFIG = _descriptor.Descriptor(
  name='InputConfig',
  full_name='input.InputConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='numOfInput', full_name='input.InputConfig.numOfInput', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numOfSupervisedInput', full_name='input.InputConfig.numOfSupervisedInput', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='supervisedInputs', full_name='input.InputConfig.supervisedInputs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=541,
)


_GETCONFIGREQUEST = _descriptor.Descriptor(
  name='GetConfigRequest',
  full_name='input.GetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='input.GetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=543,
  serialized_end=579,
)


_GETCONFIGRESPONSE = _descriptor.Descriptor(
  name='GetConfigResponse',
  full_name='input.GetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='input.GetConfigResponse.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=636,
)


_SETCONFIGREQUEST = _descriptor.Descriptor(
  name='SetConfigRequest',
  full_name='input.SetConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceID', full_name='input.SetConfigRequest.deviceID', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='input.SetConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=638,
  serialized_end=710,
)


_SETCONFIGRESPONSE = _descriptor.Descriptor(
  name='SetConfigResponse',
  full_name='input.SetConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=712,
  serialized_end=731,
)


_SETCONFIGMULTIREQUEST = _descriptor.Descriptor(
  name='SetConfigMultiRequest',
  full_name='input.SetConfigMultiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceIDs', full_name='input.SetConfigMultiRequest.deviceIDs', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='input.SetConfigMultiRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=733,
  serialized_end=811,
)


_SETCONFIGMULTIRESPONSE = _descriptor.Descriptor(
  name='SetConfigMultiResponse',
  full_name='input.SetConfigMultiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deviceErrors', full_name='input.SetConfigMultiResponse.deviceErrors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=813,
  serialized_end=879,
)

_SUPERVISEDINPUTCONFIG.fields_by_name['short'].message_type = _SUPERVISEDINPUTRANGE
_SUPERVISEDINPUTCONFIG.fields_by_name['open'].message_type = _SUPERVISEDINPUTRANGE
_SUPERVISEDINPUTCONFIG.fields_by_name['on'].message_type = _SUPERVISEDINPUTRANGE
_SUPERVISEDINPUTCONFIG.fields_by_name['off'].message_type = _SUPERVISEDINPUTRANGE
_SUPERVISEDINPUT.fields_by_name['registance'].enum_type = _SUPERVISEDREGISTANCEVALUE
_SUPERVISEDINPUT.fields_by_name['config'].message_type = _SUPERVISEDINPUTCONFIG
_INPUTCONFIG.fields_by_name['supervisedInputs'].message_type = _SUPERVISEDINPUT
_GETCONFIGRESPONSE.fields_by_name['config'].message_type = _INPUTCONFIG
_SETCONFIGREQUEST.fields_by_name['config'].message_type = _INPUTCONFIG
_SETCONFIGMULTIREQUEST.fields_by_name['config'].message_type = _INPUTCONFIG
_SETCONFIGMULTIRESPONSE.fields_by_name['deviceErrors'].message_type = err__pb2._ERRORRESPONSE
DESCRIPTOR.message_types_by_name['SupervisedInputRange'] = _SUPERVISEDINPUTRANGE
DESCRIPTOR.message_types_by_name['SupervisedInputConfig'] = _SUPERVISEDINPUTCONFIG
DESCRIPTOR.message_types_by_name['SupervisedInput'] = _SUPERVISEDINPUT
DESCRIPTOR.message_types_by_name['InputConfig'] = _INPUTCONFIG
DESCRIPTOR.message_types_by_name['GetConfigRequest'] = _GETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['GetConfigResponse'] = _GETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigRequest'] = _SETCONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetConfigResponse'] = _SETCONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetConfigMultiRequest'] = _SETCONFIGMULTIREQUEST
DESCRIPTOR.message_types_by_name['SetConfigMultiResponse'] = _SETCONFIGMULTIRESPONSE
DESCRIPTOR.enum_types_by_name['SupervisedRegistanceValue'] = _SUPERVISEDREGISTANCEVALUE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SupervisedInputRange = _reflection.GeneratedProtocolMessageType('SupervisedInputRange', (_message.Message,), dict(
  DESCRIPTOR = _SUPERVISEDINPUTRANGE,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.SupervisedInputRange)
  ))
_sym_db.RegisterMessage(SupervisedInputRange)

SupervisedInputConfig = _reflection.GeneratedProtocolMessageType('SupervisedInputConfig', (_message.Message,), dict(
  DESCRIPTOR = _SUPERVISEDINPUTCONFIG,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.SupervisedInputConfig)
  ))
_sym_db.RegisterMessage(SupervisedInputConfig)

SupervisedInput = _reflection.GeneratedProtocolMessageType('SupervisedInput', (_message.Message,), dict(
  DESCRIPTOR = _SUPERVISEDINPUT,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.SupervisedInput)
  ))
_sym_db.RegisterMessage(SupervisedInput)

InputConfig = _reflection.GeneratedProtocolMessageType('InputConfig', (_message.Message,), dict(
  DESCRIPTOR = _INPUTCONFIG,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.InputConfig)
  ))
_sym_db.RegisterMessage(InputConfig)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGREQUEST,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.GetConfigRequest)
  ))
_sym_db.RegisterMessage(GetConfigRequest)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCONFIGRESPONSE,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.GetConfigResponse)
  ))
_sym_db.RegisterMessage(GetConfigResponse)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGREQUEST,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.SetConfigRequest)
  ))
_sym_db.RegisterMessage(SetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGRESPONSE,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.SetConfigResponse)
  ))
_sym_db.RegisterMessage(SetConfigResponse)

SetConfigMultiRequest = _reflection.GeneratedProtocolMessageType('SetConfigMultiRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIREQUEST,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.SetConfigMultiRequest)
  ))
_sym_db.RegisterMessage(SetConfigMultiRequest)

SetConfigMultiResponse = _reflection.GeneratedProtocolMessageType('SetConfigMultiResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETCONFIGMULTIRESPONSE,
  __module__ = 'input_pb2'
  # @@protoc_insertion_point(class_scope:input.SetConfigMultiResponse)
  ))
_sym_db.RegisterMessage(SetConfigMultiResponse)


DESCRIPTOR._options = None

_INPUT = _descriptor.ServiceDescriptor(
  name='Input',
  full_name='input.Input',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1037,
  serialized_end=1251,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='input.Input.GetConfig',
    index=0,
    containing_service=None,
    input_type=_GETCONFIGREQUEST,
    output_type=_GETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfig',
    full_name='input.Input.SetConfig',
    index=1,
    containing_service=None,
    input_type=_SETCONFIGREQUEST,
    output_type=_SETCONFIGRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetConfigMulti',
    full_name='input.Input.SetConfigMulti',
    index=2,
    containing_service=None,
    input_type=_SETCONFIGMULTIREQUEST,
    output_type=_SETCONFIGMULTIRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_INPUT)

DESCRIPTOR.services_by_name['Input'] = _INPUT

# @@protoc_insertion_point(module_scope)
